@@ -1769,7 +1769,7 @@ def ScrewTrajectory(Xstart, Xend, Tf, N, method,type=0):
             sddot = QuinticTimeScalingDdot(Tf, timegap * i)    
         Xs = np.dot(Xstart, MatrixExp6(MatrixLog6(np.dot(TransInv(Xstart),Xend)) * s)) 
         V = Adjoint(Xs)@se3ToVec(MatrixLog6(TransInv(Xstart)@Xend)); 
-        V = Adjoint(Xstart) @ se3ToVec(MatrixLog6(TransInv(Xstart) @ Xend));
+        #V = Adjoint(Xstart) @ se3ToVec(MatrixLog6(TransInv(Xstart) @ Xend));
         if type == 0  :
             traj[i] = Xs
         elif type == 1 :
